package util;

public class Pagination {

	final private int rowSize = 10; // 한 페이지에 나올 row 수

	private int currPage; // 현재 페이지
	private int totalRow; // 총 row 수

	/* 페이징에 쓰일 필드 */
	private int pageSize = 10; // 한 화면에 보여줄 페이지 번호 갯수
	private int totalPage; // 총 페이지 번호 갯수
	private int startPage; // 시작이 되는 페이지 번호
	private int endPage; // 끝이 되는 페이지 번호


	/**
	 * 생성자로 현재 페이지와 총 로우수를 인자로 넣는다.
	 * 
	 * @param currPage
	 *            현재 페이지 번호
	 * @param totalRow
	 *            총 로우 수
	 */
	public Pagination(int currPage, int totalRow) {
		this.currPage = currPage;
		this.totalRow = totalRow;

		process(); // 페이징 계산
	}

	/**
	 * 페이징을 계산 한다.
	 */
	private void process() {
		totalPage = (int) Math.ceil((double)totalRow / (double)pageSize) - 1;
		startPage = ( ( ( currPage - 1 ) / pageSize ) * pageSize ) + 1;
		endPage = startPage + ( pageSize - 1 );
		
		if(endPage > totalPage) {
			endPage = totalPage;
		}
		
		System.out.println(toString());
	}

	@Override
	public String toString() {
		return "Pagination [currPage=" + currPage + ", rowSize=" + rowSize
				+ ", totalRow=" + totalRow + ", pageSize=" + pageSize
				+ ", startPage=" + startPage + ", endPage=" + endPage
				+ ", totalPage=" + totalPage + "]";
	}

	public String toHTML() {
		StringBuffer sb = new StringBuffer();
		
		// 처음 버튼
		if(currPage > 0) {
			sb.append(" <a href=\"javascript:goTo(1)\">처음</a> ");
		}
		// 이전 버튼(-10)
		if(currPage > 0) {
			sb.append(" <a href=\"javascript:goTo(" + ( currPage - 10 >= 1 ? currPage - 10 : 1 ) + ")\">이전</a> ");
		}
		// 페이지 번호 출력
		for(int i = startPage ; i <= endPage ; i++ ) {
			if(i == currPage) {
				sb.append(" <b>" + i + "</b> ");
			} else {
				sb.append(" <a href=\"javascript:goTo(" + i + ")\">" + i + "</a> ");
			}
		}
		// 다음 버튼(+10)
		if(currPage < totalPage) {
			sb.append(" <a href=\"javascript:goTo(" + ( currPage + 10 < totalPage ? currPage + 10 : totalPage ) + ")\">다음</a> ");
		}
		// 마지막 버튼
		if(currPage < totalPage) {
			sb.append(" <a href=\"javascript:goTo(" + totalPage + ")\">마지막</a> ");
		}
		
		return sb.toString();
	}

	/**
	 * SQL 에 쓰일 시작 row를 반환
	 * 
	 * @return
	 */
	public int getStartRow() {
		return currPage * rowSize;
	}

	/**
	 * 한 페이지에 나올 row 수를 반환한다.
	 * 
	 * @return
	 */
	public int getRowSize() {
		return rowSize;
	}

}
